@@ -1,15 +1,18 @@
 package Perinci::Tx::Manager;
 
+our $DATE = '2015-08-18'; # DATE
+our $VERSION = '0.51'; # VERSION
+
 use 5.010001;
 use strict;
 use warnings;
 use experimental 'smartmatch';
+use Log::Any::IfLOG '$log';
 
 use DBI;
 use File::Flock;
 use File::Remove qw(remove);
 use JSON;
-use Log::Any '$log';
 use Perinci::Sub::Util qw(err);
 use Scalar::Util qw(blessed);
 use Package::MoreUtil qw(package_exists);
@@ -41,8 +44,6 @@ sub action_get_code_and_meta {
 
 package Perinci::Tx::Manager;
 
-our $VERSION = '0.50'; # VERSION
-
 my $proto_v = 2;
 
 our $ep = ""; # error prefix
@@ -1393,7 +1394,7 @@ Perinci::Tx::Manager - A Rinci transaction manager
 
 =head1 VERSION
 
-This document describes version 0.50 of Perinci::Tx::Manager (from Perl distribution Perinci-Tx-Manager), released on 2014-12-05.
+This document describes version 0.51 of Perinci::Tx::Manager (from Perl distribution Perinci-Tx-Manager), released on 2015-08-18.
 
 =head1 SYNOPSIS
 
@@ -1635,7 +1636,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
