@@ -1,9 +1,12 @@
 package Test::Perinci::Tx::Manager;
 
+our $DATE = '2015-08-18'; # DATE
+our $VERSION = '0.51'; # VERSION
+
 use 5.010;
 use strict;
 use warnings;
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 
 use File::Remove qw(remove);
 use Perinci::Access::Schemeless;
@@ -12,8 +15,6 @@ use Scalar::Util qw(blessed);
 use Test::More 0.98;
 use UUID::Random;
 
-our $VERSION = '0.50'; # VERSION
-
 require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(test_tx_action);
@@ -521,7 +522,7 @@ Test::Perinci::Tx::Manager - Transaction tests
 
 =head1 VERSION
 
-This document describes version 0.50 of Test::Perinci::Tx::Manager (from Perl distribution Perinci-Tx-Manager), released on 2014-12-05.
+This document describes version 0.51 of Test::Perinci::Tx::Manager (from Perl distribution Perinci-Tx-Manager), released on 2015-08-18.
 
 =head1 FUNCTIONS
 
@@ -593,7 +594,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
